#include "project.h"
#include <stdio.h>

extern int HostMain(int16_t* );
/*******************************************************************************
* Function Name: main()
********************************************************************************
* Summary:
*  Main function for the CM4 core.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Theory:
*  The function starts BLE and UART components.
*  This function processes all BLE events. See host_main.c for details. 
*
*******************************************************************************/
int main()
{
    __enable_irq(); /* Enable global interrupts. */
    UART_Start();
    ADC_Start();
    Cy_SAR_StartConvert(SAR,CY_SAR_START_CONVERT_CONTINUOUS);
    
    int MF_Delay = 154; // 6493 Hz
    int Nb_of_Samples = 100; // 6400 lines
    int16_t value_table [100];
    
    // Gather data from the ADC and store them in the value_table array
    
    for(int i=0;i<Nb_of_Samples;i++){
        value_table[i] = Cy_SAR_GetResult16(SAR,2);
        printf("Vibration Data n#%d: %u \r\n",i,value_table[i]);
        CyDelayUs(MF_Delay);
    }    
    printf("Vibration data retreived. \r\n");
    
    
    #if(CY_BLE_CONFIG_HOST_CORE == CY_BLE_CORE_CORTEX_M4)   
    
    /* Run Host main */
    HostMain(value_table);
    
    #else
    
        /* Start BLE Controller for dual core mode */
	    Cy_BLE_Start(NULL);
       
    for(;;)
    {
         /* Process BLE events continuously for controller in dual core mode */
        Cy_BLE_ProcessEvents();
    }
    
    #endif /* (CY_BLE_CONFIG_HOST_CORE == CY_BLE_CORE_CORTEX_M4) */
}

/* [] END OF FILE */
